@@ -2,7 +2,7 @@
 Entrypoint for the generic transform block.
 """
 from importlib import import_module
-from typing import Callable, Dict, List, Optional, Union
+from typing import Callable, Dict, Optional, Tuple
 
 from pyspark.sql import DataFrame
 
@@ -46,11 +46,18 @@ def generic(conf: BlockConfig) -> DataFrame:
     return dataframe
 
 
-def _get_function_meta(function: Dict) -> List[Union[None, str]]:
+def _get_function_meta(function: Dict) -> Tuple[Optional[str], str, dict]:
     """Get the metadata for the module, function_name and parameters."""
-    module_function = next(iter(function))
     module_path = None
-    function_parameters = next(iter(function.values()))
+
+    if isinstance(function, dict):
+        module_function = next(iter(function))
+        function_parameters = next(iter(function.values()))
+    elif isinstance(function, str):
+        module_function = function
+        function_parameters = {}
+    else:
+        raise ValueError(f"Could not process function {function}")
 
     if "." in module_function:
         module_path, module_function = module_function.rsplit(".", 1)
